"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getOperationId = exports.operationIdFormatter = void 0;
const change_case_1 = require("change-case");
const DEFAULT_PATTERN = "%c.%m";
/**
 * @ignore
 */
function operationIdFormatter(pattern = "") {
    const OPERATION_IDS = new Map();
    const transform = (name, propertyKey) => {
        const str = (pattern || DEFAULT_PATTERN).replace(/%c/, name).replace(/%m/, propertyKey);
        return pattern === "" ? (0, change_case_1.camelCase)(str) : str;
    };
    return (name, propertyKey, path = "") => {
        const operationId = transform(name, propertyKey);
        const operationKey = name + propertyKey;
        if (!OPERATION_IDS.has(operationKey)) {
            OPERATION_IDS.set(operationKey, 0);
            return operationId;
        }
        // try with paths
        const result = path.match(/{(\w+)}/gi);
        if (result) {
            const operationKey = name + propertyKey + result[0];
            if (!OPERATION_IDS.has(operationKey)) {
                OPERATION_IDS.set(operationKey, 0);
                return (0, change_case_1.camelCase)(`${operationId} By ${result}`);
            }
        }
        const id = OPERATION_IDS.get(operationKey) + 1;
        OPERATION_IDS.set(operationKey, id);
        return `${operationId}_${id}`;
    };
}
exports.operationIdFormatter = operationIdFormatter;
function getOperationId(path, { store, operationIdFormatter }) {
    return operationIdFormatter(store.parent.schema.get("name") || store.parent.targetName, store.propertyName, path);
}
exports.getOperationId = getOperationId;
//# sourceMappingURL=operationIdFormatter.js.map