import { OperationVerbs } from "../../constants/OperationVerbs";
export interface RouteChainedDecorators {
    <T>(target: Object, propertyKey: string | symbol, descriptor: TypedPropertyDescriptor<T>): TypedPropertyDescriptor<T> | void;
    /**
     * @param string
     * @constructor
     */
    Path(string: string): this;
    /**
     * Set the operation method
     * @param method
     */
    Method(method: OperationVerbs | string): this;
    /**
     * Set the operation id
     * @param id
     */
    Id(id: string): this;
    /**
     * Set the operation id
     * @param name
     */
    Name(name: string): this;
    /**
     *
     * @param description
     */
    Description(description: string): this;
    /**
     * Summary
     * @constructor
     * @param Summary
     */
    Summary(Summary: string): this;
    Use(...args: any[]): this;
    UseAfter(...args: any[]): this;
    UseBefore(...args: any[]): this;
}
/**
 * Describe a new route with a method and path.
 *
 * ```typescript
 * @Controller('/')
 * export class Ctrl {
 *
 *    @Route('GET', '/')
 *    get() { }
 * }
 *
 * ```
 *
 * @returns {Function}
 * @param method
 * @param path
 * @param args
 * @decorator
 * @operation
 */
export declare function Operation(method: string, path: string, ...args: any[]): RouteChainedDecorators;
export declare function Operation(...args: any[]): RouteChainedDecorators;
